import 'package:flutter/material.dart';
import 'package:nirrti/nirrti.dart';
import 'package:nirrti/src/custom_components/custom_select/view_model.dart';

mixin ViewMixin {
  render(BuildContext context, OwlnextSelectState state) {
    return SizedBox(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Row(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.start,
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    SizedBox(
                      child: Row(
                        children: [
                          if (state.widget.label != null)
                          Flexible(
                            child: SizedBox(
                              child: Text(
                                "${state.widget.label} ${state.widget.isMandatory == true ? "* " : ""}",
                                textAlign: TextAlign.left,
                                style: Artist().labelTextStyle
                              ),
                            ),
                          ),
                          if (state.widget.infoCallback != null) 
                          InkWell(
                            child: MouseRegion(
                              cursor: SystemMouseCursors.click,
                              child: GestureDetector(
                                onTap: () {
                                  state.widget.infoCallback!();
                                },
                                child: Container(
                                  width: 17,
                                  height: 17,
                                  padding: const EdgeInsets.all(2),
                                  decoration: BoxDecoration(
                                    border: Border.all(
                                      color: Theme.of(context).colorScheme.primary,
                                    ),
                                    borderRadius: BorderRadius.circular(100)
                                  ),
                                  child: Icon(
                                    Icons.question_mark,
                                    color: Theme.of(context).colorScheme.primary,
                                    size: 10
                                  )
                                )
                              )
                            )
                          )
                        ]
                      ),
                    ),
                    SizedBox(
                      height: Artist().labelBottomSpace,
                    ),
                    ConstrainedBox(
                      constraints: BoxConstraints(
                        minWidth: 250,
                        maxWidth: Artist().maxInputWidth,
                      ),
                      child: DropdownButtonFormField(
                        key: state.renderKey,
                        isDense: true,
                        isExpanded: true,
                        padding: const EdgeInsets.all(0),
                        decoration: Artist().inputDecoration,
                        value: state.widget.value,
                        items: state.currentItems, 
                        onChanged: state.widget.enabled == false ?
                          null
                        : (Object? value) { 
                          state.widget.onChanged(value.toString());
                        },
                        style: Theme.of(context).textTheme.bodyMedium,
                        dropdownColor: Colors.white,            
                        validator: (value) {
                          if (state.widget.isMandatory == true && value == null) {
                            return 'Merci de sélectionner une option';
                          }
                                  
                          return null;
                        },
                      ),
                    )
                  ]
                ),
              ),
              if (state.widget.addButtonCallback != null)
              const SizedBox(
                width: 12,
              ),
              if (state.widget.addButtonCallback != null)
              Padding(
                padding: const EdgeInsets.only(top: 12),
                child: InkWell(
                  onTap: () {
                    state.widget.addButtonCallback!(); 
                  },
                  child: MouseRegion(
                    cursor: SystemMouseCursors.click,
                    child: GestureDetector(
                      child: Icon(
                        Icons.add,
                        color: Theme.of(context).colorScheme.primary
                      )
                    )
                  )
                ),
              )
            ],
          ),
        ],
      ),
    );
  }
}